@@ -12,11 +12,16 @@ class Orders(Base):
     def get(self, order_id, **params):
         if not order_id or not order_id.startswith(self.RESOURCE_ID_PREFIX):
             raise IdentifierError(
-                "Invalid order ID: '{id}'. An order ID should start with '{prefix}'.".format(
-                    id=order_id, prefix=self.RESOURCE_ID_PREFIX
-                )
+                f"Invalid order ID: '{order_id}'. An order ID should start with '{self.RESOURCE_ID_PREFIX}'."
             )
-        return super().get(order_id, **params)
+
+        result_order = super().get(order_id, **params)
+
+        requested_embeds = self.extract_embed(params)
+        if requested_embeds:
+            result_order.requested_embeds = requested_embeds
+
+        return result_order
 
     def delete(self, order_id, data=None):
         """Cancel order and return the order object.
@@ -26,9 +31,7 @@ class Orders(Base):
         """
         if not order_id or not order_id.startswith(self.RESOURCE_ID_PREFIX):
             raise IdentifierError(
-                "Invalid order ID: '{id}'. An order ID should start with '{prefix}'.".format(
-                    id=order_id, prefix=self.RESOURCE_ID_PREFIX
-                )
+                f"Invalid order ID: '{order_id}'. An order ID should start with '{self.RESOURCE_ID_PREFIX}'."
             )
         result = super().delete(order_id, data)
         return self.get_resource_object(result)
