@@ -12,7 +12,7 @@ class Profiles(Base):
     def get(self, profile_id, **params):
         if not profile_id or (not profile_id.startswith(self.RESOURCE_ID_PREFIX) and not profile_id == "me"):
             raise IdentifierError(
-                "Invalid profile ID: '{id}'. A profile ID should start with '{prefix}' "
-                "or it should be 'me'.".format(id=profile_id, prefix=self.RESOURCE_ID_PREFIX)
+                f"Invalid profile ID: '{profile_id}'. A profile ID should start with '{self.RESOURCE_ID_PREFIX}' "
+                "or it should be 'me'."
             )
         return super().get(profile_id, **params)
